package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,``P`!````,!8``#0```!8P0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````#*X`
M``RN```%`````!````$```#0O0``T,T``-#-``!``@``A!(```8`````$```
M`@```-R]``#<S0``W,T``/````#P````!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&1@GP``8)\``&"?``#L````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DT+T`
M`-#-``#0S0``,`(``#`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`T7`.;WH]$C*9JJ@ZV_4'$>Y,ILD1````3`````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````3````%````!4````50``
M`%L```!<````70```%\```!@`````````&(```!D````90```&8`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"I`@``````
M```````2````5P,`````````````$@```/X!`````````````!(````1````
M```````````@````<`,`````````````$0```-8#`````````````!(```#V
M`@`````````````1````2`,`````````````$@```"4!`````````````!(`
M``#$`@`````````````2````R```````````````$@```)<!````````````
M`!(```"P`@`````````````2````F```````````````$@```"`!````````
M`````!(```!Z`P`````````````2````_0(`````````````$@```!4!````
M`````````!$```!X`@`````````````2````>P$`````````````$@```/<`
M`````````````!$````$`P`````````````2````20$`````````````$@``
M`-8``````````````!(````K`P`````````````B````Q0$`````````````
M$@```$<"`````````````!(```#V`0`````````````2````E`(`````````
M````$@```+(!`````````````!(```"%`@`````````````2````O@$`````
M````````$@```%<!`````````````!(````-`P`````````````2````+0``
M````````````(````%D"`````````````!(```#0`0`````````````1````
M&@,`````````````$@```'@``````````````!(```"B`@`````````````2
M````7@,`````````````$@```.\!`````````````!(```"G````````````
M```2````LP``````````````$@```'`!`````````````!(```!_`@``````
M```````2````9@(`````````````$@```#8!`````````````!(````7`@``
M```````````2````C0(`````````````$@```&H``````````````!(````J
M`0`````````````2````RP(`````````````$@```*<!`````````````!(`
M```$`0`````````````2````4`,`````````````$@```)L"````````````
M`!(```!Q`P`````````````A````B0$`````````````$@```(<`````````
M`````!(````\```````````````@````Z```````````````$@```&<!````
M`````````!(````A`P`````````````2````M@(`````````````$@```%``
M`````````````"````!>`@`````````````2````<@,`````````````$0``
M`.P"`````````````!(````#`@`````````````2````V0(`````````````
M$@```"@"`````````````!(```!O`@`````````````2````Y`(`````````
M````$@```#H#`````````````!(```#?`P``8%T``'L````2``T`K0,``*1>
M````````$@`.``0$``"P3```*0T``!(`#0!K`P``\!,``$`"```2``T`LP,`
M`&!%```%````$@`-`&H$``!P10``'0(``!(`#0!D!```S!$````````2``H`
MEP0``.!9``"``P``$@`-`)(#```0T````````!``&`#K`P``D$<``"(````2
M``T`.`(``+Q>```$````$0`/`)X#``!4X````````!``&`!B!```\$,``#L`
M```2``T`=P0``%!+``!:`0``$@`-`(D$``"02@``>0```!(`#0`1!````-``
M```````0`!<`^`,``,!'``#L````$@`-`(L#```0T````````!``%P!$!```
M#-````0````1`!<`HP,``(!>```"````$@`-`#0$```@7@``70```!(`#0`7
M!```,!8````````2``T`$P0```#0````````(``7`$X$``"X7@``!````!$`
M#P#$`P``$$L``#0````2``T`'@0``)!$``#)````$@`-`%4$``"P2```V0$`
M`!(`#0``;&EB<&5R;"YS;RXU+C(T`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N
M<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`
M7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S
M960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L
M;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`
M7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T
M9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D
M9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<W1A
M8VM?8VAK7V9A:6P`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P7VAW`'!A<E]I;FET7V5N
M=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)
M0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,2XS`$=,
M24)#7S(N-``````"``(``P````(``@`"``(``@`"```````"```````$``(`
M```"```````"```````%````!@`'``(````"``(````(`````@````(````"
M``(`!P`````````"``(````#``(```````@```````(``@`"````````````
M```)``@````"``(`"0`#``D``P`"``(`"``!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``@#?`0``
M$````#`````2:6D-```'`*T$```0````$&EI#0```P"W!`````````$`!@`N
M`@``$``````````2:6D-```)`*T$```0````=!EI"0``"`#!!```$````'(9
M:0D```8`S00``!````!S'VD)```%`-D$```0````%&EI#0``!`#E!```$```
M`!!I:0T```(`MP0```````#0S0``"````-3-```(````M,\```@````$T```
M"`````S0```(````V,X```8!``#<S@``!@(``.#.```&`P``Y,X```8$``#H
MS@``!@8``.S.```&!P``\,X```8(``#TS@``!@D``/C.```&"@``_,X```8+
M````SP``!@P```3/```&#0``",\```8.```,SP``!@\``!#/```&$```%,\`
M``81```8SP``!A(``!S/```&$P``(,\```84```DSP``!A4``"C/```&%@``
M+,\```87```PSP``!A@``#3/```&&0``.,\```8:```\SP``!AL``$#/```&
M'```1,\```8=``!(SP``!AX``$S/```&'P``4,\```8@``!4SP``!B$``%C/
M```&(@``7,\```8C``!@SP``!B0``&3/```&)0``:,\```8F``!LSP``!B<`
M`'#/```&*```=,\```8I``!XSP``!BH``'S/```&*P``@,\```8L``"$SP``
M!BT``(C/```&+@``C,\```8O``"0SP``!C```)3/```&,0``F,\```8R``"<
MSP``!C,``*#/```&-```I,\```8U``"HSP``!C8``*S/```&-P``L,\```8X
M``"XSP``!CD``+S/```&.P``P,\```8\``#$SP``!CT``,C/```&/@``S,\`
M``8_``#0SP``!D```-3/```&00``V,\```9"``#<SP``!D,``.#/```&1```
MY,\```9%``#HSP``!D8``.S/```&1P``\,\```9(``#TSP``!DD``/C/```&
M2@``_,\```9+``!3@^P(Z)L$``"!P_>\``"+@Y````"%P'0%Z/8```"#Q`A;
MPP#_LP0```#_HP@`````````_Z,,````9I#_HQ````!FD/^C%````&:0_Z,<
M````9I#_HR0```!FD/^C*````&:0_Z,L````9I#_HS````!FD/^C.````&:0
M_Z,\````9I#_HT````!FD/^C1````&:0_Z-(````9I#_HU````!FD/^C5```
M`&:0_Z-<````9I#_HV````!FD/^C9````&:0_Z-H````9I#_HVP```!FD/^C
M<````&:0_Z-T````9I#_HW@```!FD/^C?````&:0_Z.`````9I#_HX0```!F
MD/^CB````&:0_Z.,````9I#_HY````!FD/^CE````&:0_Z.<````9I#_HZ``
M``!FD/^CI````&:0_Z.H````9I#_HZP```!FD/^CL````&:0_Z.T````9I#_
MH[@```!FD/^CO````&:0_Z/`````9I#_H\@```!FD/^CS````&:0_Z/0````
M9I#_H]0```!FD/^CV````&:0_Z/<````9I#_H^````!FD/^CY````&:0_Z/L
M````9I#_H_````!FD/^C_````&:0_Z,``0``9I#_HP0!``!FD/^C"`$``&:0
M_Z,0`0``9I#_HQ@!``!FD/^C'`$``&:0_Z,@`0``9I#_HR0!``!FD/^C*`$`
M`&:0_Z,L`0``9I#_HS`!``!FD(U,)`2#Y/#_<?Q5B>575E-1B<[H:`(``('#
MQ+H``(/L+(M!!(E%U(M!"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z,+^__^+
M@\0```"#Q`Q04/^S]````.B420``BX-8````@\00@#@`#X0F`0``B[M,````
M@^P,_S?H4O___X"(^@(```):_S?H0____X"(^@(```&+!H/$$(/`!3W___\_
M#X=9`0``@^P,P>`"4.@5_O__BWW4BS:#Q!")@W@1``#'@WP1```$````BQ>#
M_@&)$(V3ZI'__XE0!(N30`$``(E0"(V3[9'__XE0#+H!````?A*-="8`BPR7
MB4R0#(/"`3G6=?*#[`S'1+`,`````(/&`VH`4(V#9'7__U90_[.$$0``Z$[^
M__^#Q""%P(G&#X26````@^P,_[.$$0``C7W@Z#C]__^-@Y.0__^)^NC[)P``
M@\00A<`/A(4```"#[`S_LX01``#H\OS__^CM_?__@\00B?"+?>1E,ST4````
M#X6I````C67P65M>7UV-8?S#Z`_]__^%P(F#A!$```^$CP```(/L#%#HJ/S_
M_XN[3````%G_-^@2_O__@\00QH!I!0```.FG_O__@^P,_[.$$0``Z,W]__^#
MQ!")QNE2____BX.`$0``A<!T)8/L#%#H>$<``(/$$.E@____4%"-@T.0____
MLY@```!0Z!S]__^-@TB0__^)^N@O)P``A<")@X`1```/A#'____KONAJ2```
M@^P,:@'HN/S__S'M7HGA@^3P4%12Z"(```"!PXRX``"-@[2/__]0C8-4C___
M4%%6_[/H````Z*?\___TBQPDPV:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0
MZ!<!``"!PD>X``"-BD0!``"-@D<!```IR(/X!G87BX(8````A<!T#56)Y8/L
M%%'_T(/$$,GSPXGVC;PG`````.C7````@<('N```58V*1`$``(V"1`$``(GE
M4RG(P?@"@^P$B</!ZQ\!V-'X=!2+D@P!``"%TG0*@^P(4%'_TH/$$(M=_,G#
MB?:-O"<`````58GE4^A7____@<.SMP``@^P$@+M4`0```'4GBX-H````A<!T
M$8/L#/^S.`$``.A-^___@\00Z#7____&@U0!```!BUW\R<.)]HV\)P````#H
M-P```('"9[<``(V"#/___XL(A<EU">E$____C70F`(N2^````(72=.U5B>6#
M[!10_]*#Q!#)Z23___^+%"3#55>-:#A64X'L#`,``(E$)$R-1"1XB70D$&6+
M'10```")G"3\`@``,=N)1"0(B7PD%(G!D(UT)@"+5)T`BT2=!,=$V00`````
MQT39#`````#'1"0$``````_*B00DB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'
MBP0DP>(8P>`("=<E``#_``GXB439"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)
MQ9"-="8`BU5HBT5L@\4(,U4X,T4\,U4(,T4,,U7X,T7\QT5\`````(G'B=")
MT0^L^!\!T0G!B4UX.RPD=<B+1"1,BW`,BT@<BU@(BSB+:`2+4!B)="0<B4PD
M#(MP%(M(((E<)!B+6!");"04B50D"#'2B4PD6(ET)`2)^8G^B1PDBU@D#ZSI
M&\'F!8E\)!")]8MT)%B)7"1<"<T#="1XBWPD7!-\)'R)Z(GQ@<&9>8):B?N#
MTP`!R(M,)!@1VHL<)(E$)"")5"0DBU0D"(G?,=<ASXGZBWPD"(MT)""+1"08
MQT0D)`````#'1"0T`````#'Z`=:+5"0<B<>)="0@B70D*,'G'HG&B?F+?"0(
M#ZS6`HG-BP0DBU0D)`GU`[PD@````(EL)#"+;"0,$ZPDA````(GY@<&9>8):
MB>N+;"0PB4PD.(/3`(M,)#B)7"0\QT0D/``````QQ8M$)!")[R''BT0D((G[
MBSPDB<8Q^XG'BT0D$`'9P>8%B70D.(MT)#B)RP^LUQN+5"04B<$)_@'SP>$>
M,?\/K-`"B<V+5"0PB5PD4`G%B6PD.(ML)"#WU2'JBVPD*"-L)#C'1"0L````
M`,=$)$0`````B>B)U8M4)"0)Q8L$)`.$)(@```")Z<=$)"0`````!9EY@EH!
MP8G8P>`%B40D*(G8BVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)"B)3"1@B<'!
MX1X/K-`"B<V+5"0X"<6+1"0PB6PD0(G=]]4AZHML)%`C;"1`">H#A"20````
MB=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD
M,`'IB?V)WP^L[P+!XAZ)3"10B4PD((G5"?V);"0PQT0D-`````"+;"0HBU0D
M0(MT)#C'1"0\`````/?5(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"28````B>F)
M\`69>8):`<&+1"0@B<N)QHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P<=$
M)"P`````"?X!\\'A'C'_#ZS0`HG-BU0D,(E<)&`)Q8M$)$");"0XBVPD(/?5
M(>J+;"10(VPD.`GJ`X0DH````(G1BU0D)`69>8):`<&)V,'@!8E$)"B)V(ML
M)"@/K/@;B40D0`ML)$"+1"0@`>F)3"10B4PD*(G!P>$>#ZS0`HG-B=H)Q??2
MB6PD0"-4)#B+;"1@(VPD0(M$)#"+="0XQT0D)`````#'1"1$`````,=$)#0`
M````">H#A"2H````B=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/
MK-`;B=J)1"0P"VPD,`'IB?V)WP^L[P+!XAZ)3"0@B4PD8(G5BU0D0`G]B6PD
M,(ML)"CWU2'JBVPD4"-L)#")Z(G5BU0D)`G%`[0DL````(GIB?`%F7F"6@'!
MBT0D((G+B<:)QXM$)"C!Y@6)="0XBW0D.`^LUQN)P0G^`?/!X1XQ_XE<)%"+
M5"0LB<W'1"0L`````,=$)#P`````QT0D1``````/K-`"BU0D,`G%BT0D0(EL
M)#B+;"0@]]4AZHML)&`C;"0X">H#A"2X````B=&+5"0D!9EY@EH!P8G8P>`%
MB40D*(G8BVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"
MB<V)V@G%]](C5"0XB6PD0(ML)%`C;"1`BT0D,`GJ`X0DP````(G1BU0D+`69
M>8):`<&+1"0HP>`%B40D((M$)"@/K-`;B=J)1"0PBVPD(`ML)#"+="0XQT0D
M)`````#'1"0T`````,=$)#P``````>F)_8G?#ZSO`L'B'HE,)"")3"10B=6+
M5"1`"?V);"0PBVPD*/?5(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3(````B>F)
M\`69>8):`<&+1"0@B<N)QHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P0G^
M`?/!X1XQ_P^LT`*)S8M4)#")7"1@"<6+1"1`B6PD.(ML)"#WU2'JBVPD4"-L
M)#@)Z@.$)-````")T069>8):`<&)V,'@!8E$)"B)V`^L^!N)1"1`BVPD*`ML
M)$"+1"0@BU0D),=$)"P`````QT0D1`````#'1"0D`````,=$)#0`````BW0D
M.`'IB4PD*(E,)%")P<'A'@^LT`*)S8G:"<7WTB-4)#B);"1`BVPD8"-L)$"+
M1"0P">H#A"38````B=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/
MK-`;B=J)1"0P"VPD,`'IB?V)WP^L[P+!XAZ)3"1@B4PD((G5BU0D0`G]B6PD
M,(ML)"CWU2'JBVPD4"-L)#")Z(G5"<4#M"3@````BU0D)(GIQT0D/`````#'
M1"1$`````(GP!9EY@EH!P8M$)"")RXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;
MBU0D+(G!QT0D+``````)_@'SP>$>,?\/K-`"B<V+5"0PB5PD4`G%BT0D0(EL
M)#B+;"0@]]4AZHML)&`C;"0X">H#A"3H````B=&+5"0D!9EY@EH!P8G8P>`%
MB40D*(G8BVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)&")3"0HB<'!X1X/K-`"
MB<V)V@G%]](C5"0XB6PD0(ML)%`C;"1`BT0D,(MT)#C'1"0D`````,=$)#0`
M````QT0D/``````)Z@.$)/````")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+
M1"0HBVPD(`^LT!N)VHE$)#`+;"0P`>F)_8G?#ZSO`L'B'HE,)"")3"10B=6+
M5"1`"?V);"0PBVPD*/?5(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3X````B>F)
M\`69>8):`<&+1"0@B<N)QHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P0G^
M`?/!X1XQ_P^LT`*)S8E<)&`)Q8EL)#B+;"0@BU0D,(M$)$#'1"0L`````/?5
M(>J+;"10(VPD.`GJ`X0D``$``(G1BU0D),=$)"0`````!9EY@EH!P8G8P>`%
MB40D*(G8BVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)"B)3"10B<'!X1X/K-`"
MB<V)V@G%]](C5"0XB6PD((ML)&`C;"0@BT0D,`GJ`X0D"`$``(G1BU0D+`69
M>8):`<&+1"0HP>`%B40D,(M$)"B+;"0P#ZS0&XG:B40D0`ML)$`!Z8G]B=\/
MK.\"P>(>B4PD8(E,)##'1"0T`````(ML)"B)TXM4)"`)^XMT)#B)7"1HB5PD
M0/?5QT0D1`````#'1"0D`````"'JBVPD4"'=B>B)U8M4)#0)Q0.T)!`!``")
MZ8GP!9EY@EH!P8M$)#")RXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!
M"?X!\\'A'C'_#ZS0`HG-BTPD((G>"<4#C"08`0``B5PD4(M<)&B);"0XBU0D
M-(G(!:'KV6XQZXML)&`QW8GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D*`ML
M)"B+1"0P`>F)3"1@B4PD((G!P>$>#ZS0`HG+BU0D0`G#`Y0D(`$``(ML)%")
M7"1`QT0D+`````")T(M4)"0%H>O9;C-<)#@QW8GSB>D!P8M$)"#!X`6)1"0H
MBT0D((ML)"@/K-`;B?*)1"0P"VPD,`'IP>(>#ZS[`HG5BY0D*`$``(E,)"@)
MW8E,)%"+7"1`BTPD.(EL)#B!PJ'KV6Z)T(M4)"@!R#'KBVPD8(M,)"@QW8M<
M)"R)[@'&P>(%BT0D((E4)#"+;"0P#ZS9&XM4)"2)\PG-B<$!Z\'A'C'_#ZS0
M`HG-BXPD,`$``(E<)&`)Q8M$)$")WHEL)#"+;"0X@<&AZ]EN`<@S;"0PBU0D
M+#-L)%#'1"0D`````,=$)"P`````B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)
M1"1`"VPD0(M$)"@!Z8E,)"")3"10B<'!X1X/K-`"B<N+C"0X`0``BU0D)`G#
MBT0D.(G=B5PD.(M<)#"!P:'KV6X!R#'KBVPD8#'=BYPD0`$``(GI`<&+1"0@
MP>`%B40D*(M$)""+;"0H#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)
M3"0HB4PD8`GU@<.AZ]ENB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0H
MBU0D+(G&B<>+1"0@P>8%B70D,(MT)#`/K-<;BU0D),=$)"0`````"?X!\3'_
MB<Z)3"10B<'!X1X/K-`"B<V+C"1(`0``BU0D+`G%BT0D.(EL)#"+;"1`@<&A
MZ]EN`<@S;"0P,VPD8(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D.`ML)#B+
M1"0H`>F)3"0@B4PD8(G!P>$>#ZS0`HG+BXPD4`$``(M4)"0)PXM$)$")W8E<
M)#B+7"0P@<&AZ]EN`<@QZXML)%`QW8GI`<&+1"0@P>`%B40D*(M$)""+;"0H
M#ZS0&XGRB40D0`ML)$"+G"18`0``BT0D,,=$)"P``````>G!XAX/K/X"B=6)
M3"10B4PD*`GU@<.AZ]ENBU0D+(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)Z0'!
MBT0D*(G+B<:)QXM$)"#!Y@6)="0PBW0D,`^LUQN+5"0DB<''1"0D``````G^
M`?/!X1XQ_P^LT`*)S8N,)&`!``"+5"0L"<6+1"0XB=Z);"0PBVPD0('!H>O9
M;HE<)&`!R#-L)#`S;"10B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"0X"VPD
M.(M$)"@!Z8E,)%")3"0@B<'!X1X/K-`"B<N+C"1H`0``"<.+1"1`BU0D)(E<
M)#B)W8M<)#"!P:'KV6['1"0L``````'(,>N+;"1@,=V+G"1P`0``B>D!P8M$
M)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)
MU8E,)&")3"0H"?6!PZ'KV6Z+5"0LB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI
M`<&+1"0HB<N)QHG'BT0D(,'F!8ET)#"+="0P#ZS7&XM4)"2)P0G^`?/!X1XQ
M_P^LT`*)S8N,)'@!``")7"10"<6+1"0XB=Z);"0PBVPD0('!H>O9;@'(,VPD
M,#-L)&")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XM4)"S'1"0D`````(E$)#@+
M;"0XBT0D*,=$)"P``````>F)3"0@B4PD8(G!P>$>#ZS0`HG+BY0D@`$```G#
MBT0D0(G=B5PD.(M<)#"!PJ'KV6X!T(M4)"0QZXML)%`QW8N<)(@!``")Z0'!
MBT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$)$`+;"1`BT0D,`'IP>(>#ZS^
M`HG5B4PD*(E,)%`)]8'#H>O9;HM4)"R)[XML)#@!V(E\)$`Q_8GNBVPD8#'U
MB>D!P8M$)"B)QHG'P>8%B70D,(MT)#`/K-<;"?X!\3'_B4PD8(M$)"")SHM4
M)"3'1"0D`````(G!P>$>#ZS0`HG-BXPDD`$``(M4)"P)Q8M$)#C'1"0L````
M`(EL)#"+;"1`@<&AZ]EN`<@S;"0P,VPD4(GI`<&)\,'@!8E$)"")\(ML)"`/
MK/@;B40D.`ML)#B+1"0H`>F)3"0@B4PD4(G!P>$>#ZS0`HG+BXPDF`$``(M4
M)"0)PXM$)$")W8E<)#B+7"0P@<&AZ]EN`<@QZXML)&`QW8GI`<&+1"0@P>`%
MB40D*(M$)""+;"0H#ZS0&XGRB40D0`ML)$`!Z<'B'@^L_@*)U8E,)&")3"0H
M"?6+G"2@`0``BT0D,(GOBVPD.(M4)"R)?"1`QT0D-`````"!PZ'KV6X!V#']
MB>Z+;"10,?6)Z8ML)&`!P8M$)"B)RXG&B<>+1"0@P>8%B70D,(MT)#`/K-<;
MBU0D)(G!QT0D)``````)_@'SP>$>#ZS0`HG.BY0DJ`$``(M,)$`)QHM$)#B)
M7"0PB?>)7"10@<*AZ]EN`=`Q\8M4)#0QS8GI`<&+1"0PP>`%B40D((M$)#"+
M;"0@#ZS0&XM4)"R)1"0X"VPD.(M$)"@!Z8E,)&")3"0@B<'!X1X/K-`"B<Z+
ME"2P`0``B?D)QHM$)$")?"1HBVPD4(M\)""!PJ'KV6Z)="0XBUPD.`'0,?&+
M5"0T,<W'1"0L`````,=$)#0`````B>F+;"0D`<&)^,'@!8E$)"B)^`^LZ!N+
M;"0H"<6+1"0P`>F)3"10B4PD*(G'B<&+1"1@#ZS7`L'A'HG:B<T)_8G?BUPD
M+`GO(>J);"1`(?B+?"0DB<$)T8M4)"B)SHN,)+@!``"!P=R\&X^)R(M,)&@!
MR(M,)"@!QL'B!8M$)%")5"0PBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD
M8`^L_@+!X1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?HAVHG%"=6+E"3``0``
MB>Z!PMR\&X^)T(M4)#`!R`'&P>(%B50D((M,)#"+7"0TBVPD((M\)"R+1"1@
MQT0D)`````#'1"0L``````^LV1N)\XMT)"@)S0'KB?&)7"0@B5PD:`^L_@*+
M?"10P>$>B<N+3"1`"?.)^HE<)#@)VB'0B?HAVHG%BUPD)`G5BY0DR`$``(GN
M@<+<O!N/B="+5"0@`<B+3"0@`<:+1"1HP>(%B?>+="0PB50D*(ML)"@/K-D;
MBUPD.(N4)-`!```)S8GQ`>_!X1Z)?"0HB7PD8(G-BWPD-(G9#ZS^`@GU">DA
MZXEL)$`AR(G!"=F!PMR\&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H`<;!X@6)
M5"0PBVPD,`^LV1N)\XMT)""+?"0D"<V+1"1@QT0D-``````!Z\=$)"0`````
MB?&)7"1HB5PD,`^L_@+!X1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?J+?"0L
M(=J)Q8M<)#0)U8N4)-@!``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D:,'B
M!8E4)""+;"0@#ZS9&XGSBW0D*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)
MRXM,)$`)\XGZB5PD.`G:(=")^B':B<6+7"0D"=6+E"3@`0``B>Z!PMR\&X^)
MT(M4)"`!R(M,)"`!QL'B!8GWB50D*(ML)"@/K-D;"<T![XE\)&B)?"0HBW0D
M,(M\)#2+7"0XBT0D8(N4).@!``#'1"0L`````(GQQT0D-``````/K/X"P>$>
MBWPD),=$)"0`````B<V)V0GU">DAZXEL)$`AR(G!"=F!PMR\&X^+7"0LB<Z+
M3"10B="+5"0H`<B+3"0H`<;!X@6+1"1HB50D,(ML)#`/K-D;B?.+="0@"<T!
MZXGQB5PD,(E<)&`/K/X"P>$>BUPD0(G/BTPD.`GWB?J)?"10"=HAT(GZ(=J)
MQ8M<)#0)U8N4)/`!``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&P>(%B50D((ML
M)"`/K-D;B?.+="0H"<T!ZXE<)&B)7"0@B?&+?"0LP>$>BT0D8(G+BTPD0,=$
M)"P`````#ZS^`HM\)%`)\XE<)#B)^@G:(=")^B':B<6+7"0D"=6+E"3X`0``
MB>Z!PMR\&X^)T(M4)"`!R(M,)"`!QHM$)&C!X@6)]XMT)#")5"0HBVPD*`^L
MV1N+7"0XBY0D``(```G-B?$![\'A'HE\)"B)?"1@B<V+?"0TB=G'1"0T````
M``^L_@*+?"0D"?4)Z2'KB6PD0"'(B<$)V8'"W+P;CXM<)"R)SHM,)%")T(M4
M)"@!R(M,)"@!QL'B!8E4)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)&B)7"0P
M#ZS^`L'A'HM<)$"+1"1@B<^+3"0XQT0D)``````)]XGZB7PD4`G:(=")^HM\
M)"PAVHG%BUPD-`G5BY0D"`(``,=$)"P`````B>Z!PMR\&X^)T(M4)#`!R(M,
M)#`!QHM$)&C!X@6)5"0@BVPD(`^LV1N)\XMT)"@)S0'KB?&)7"0@B5PD8`^L
M_@*+?"10P>$>B<N+3"1`"?.)^HE<)#@)VB'0B?HAVHG%BUPD)`G5BY0D$`(`
M`(GN@<+<O!N/B="+5"0@`<B+3"0@`<:+1"1@P>(%B?>+="0PB50D*(ML)"@/
MK-D;BUPD.`G-B?$![\'A'HE\)&B)?"0HB<V+?"0TB=D/K/X""?4)Z2'KB6PD
M0"'(BY0D&`(``(M\)"2)P<=$)#0`````QT0D)``````)V8M<)"R)SHM,)%"!
MPMR\&X^)T(M4)"@!R(M,)"@!QL'B!8M$)&B)5"0PBVPD,`^LV1N)\XMT)"`)
MS0'KB?&)7"0PB5PD8`^L_@+!X1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?J+
M?"0L(=J)Q8M<)#0)U8N4)"`"``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D
M8,'B!8E4)""+;"0@#ZS9&XGSBW0D*`G-`>N)\8E<)&B)7"0@#ZS^`HM\)%#!
MX1Z)RXM,)$`)\XGZB5PD.`G:(=")^B':B<4)U8N4)"@"``")[H'"W+P;CXG0
MBU0D((M<)"0!R(M,)"#'1"0L``````'&BT0D:,'B!8GWBW0D,(E4)"B+;"0H
M#ZS9&XM<)#B+E"0P`@``"<V)\0'OP>$>B7PD*(E\)&")S8M\)#2)V<=$)#0`
M````#ZS^`HM\)"0)]0GI(>N);"1`(<B)P0G9@<+<O!N/BUPD+(G.BTPD4(G0
MBU0D*`'(BTPD*`'&P>(%BT0D8(E4)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<
M)#")7"1H#ZS^`L'A'HM<)$")SXM,)#@)]XGZB7PD4`G:(=")^B':B<4)U8N4
M)#@"``")[H'"W+P;CXG0BU0D,`'(`<;!X@6)5"0@BTPD,(M<)#2+;"0@BWPD
M+(M$)&C'1"0D`````,=$)"P`````#ZS9&XGSBW0D*`G-`>N)\8E<)"")7"1@
M#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD.`G:(=")^B':B<6+7"0D"=6+E"1`
M`@``B>Z!PMR\&X^)T(M4)"`!R(M,)"`!QHM$)&#!X@6)]XMT)#")5"0HBVPD
M*`^LV1N+7"0XBY0D2`(```G-B?$![\'A'HE\)"B)?"1HB<V+?"0TB=D/K/X"
M"?4)Z2'KB6PD0"'(B<$)V8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!
MQL'B!8E4)#"+;"0P#ZS9&XGSBW0D((M\)"0)S8M$)&C'1"0T``````'KQT0D
M)`````")\8E<)#")7"1@#ZS^`L'A'HM<)$")SXN,)%0"```)]XGZB7PD4`G:
M(=")^C'_(=J)Q0G5BY0D4`(``(GN@<+<O!N/@]$`B=`QVXG*BTPD.`'(BTPD
M,!':`<:+7"0T$=>+5"0P#ZS9&\'B!8GSB?Z)5"0@BVPD(#'2BWPD+`G-`>N+
M;"10$=:+E"18`@``B5PD((ET)&R+="0HB5PD:(M<)"2)\0^L_@+!X1Z)\(G.
MBTPD0`G&@<+6P6+*B="+5"0@B70D.`'(,?6)Z8ML)&`QS8M,)"")[@'&P>(%
MB50D*(ML)"@/K-D;BWPD,(GSBY0D8`(```G-QT0D+``````!ZXML)#3'1"0T
M`````(GYB5PD8(E<)"C!X1Z+7"1H#ZSO`HG-BTPD4`G]@<+6P6+*BWPD)(G0
MBU0D*(EL)$`!R(M,)#@QZ3'+BTPD*(G>BUPD+`'&P>(%BT0D.(E4)#"+;"0P
M#ZS9&XGSBW0D((M4)#0)S0'KBVPD8(GQB5PD,(E<)%#!X1Z+7"1`#ZS^`HG/
MBXPD:`(```GWB7PD.('!UL%BR@'(,?LQW8GI`<&+1"0PB<N)Q@^LT!O!Y@6)
M1"0@BVPD(`GU`>N)7"1@B5PD(,=$)"0`````BW0D*(M\)"R+;"0XBT0D0(M4
M)"2)\<=$)"P`````#ZS^`L'A'@GQB<Z+C"1P`@``B70D0('!UL%BR@'(,?6)
M[HML)%`Q]8GI`<&+1"0@B<?!YP6)?"0HB<>+="0H#ZS7&XM$)#"+5"0T"?X!
M\3'_B<Z)3"10B<'!X1X/K-`"B<V+E"1X`@``"<6+1"0XB6PD,(ML)$"!PM;!
M8LH!T#-L)#"+5"0D,VPD8(GI`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D.`ML
M)#B+1"0@`>F)3"1@B4PD*(G!P>$>#ZS0`HG+BXPD@`(```G#BT0D0(G=B5PD
M.(M<)#"!P=;!8LJ+5"0LQT0D)``````!R#'KBVPD4#'=BYPDB`(``(GI`<&+
M1"0HP>`%B40D((M$)"B+;"0@#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"
MB=6)3"10B4PD(`GU@</6P6+*BU0D)(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)
MZ0'!BT0D((G+B<:)QXM$)"C!Y@6)="0PBW0D,`^LUQN+5"0LB<$)_@'SP>$>
M,?\/K-`"B<V+C"20`@``B5PD8`G%BT0D.(G>B6PD,(ML)$"!P=;!8LH!R#-L
M)#`S;"10B>D!P8G8P>`%B40D*(G8#ZSX&XE$)#B+;"0H"VPD.(M$)""+5"0D
MQT0D+`````#'1"0D``````'IB4PD4(E,)"B)P<'A'@^LT`*)RXN,))@"``"+
M5"0L"<.+1"1`B=V)7"0XBUPD,('!UL%BR@'(,>N+;"1@,=V+G"2@`@``B>D!
MP8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L
M_@*)U8E,)"")3"1@"?6!P];!8LJ+5"0DB>^+;"0X`=B)?"1`,?V)[HML)%`Q
M]8GI`<&+1"0@B<N)QHG'P>8%B70D,(MT)#`/K-<;"?X!\S'_B5PD4(M$)"B)
MWHM4)"S'1"0L`````(G!P>$>#ZS0`HG-BXPDJ`(``(M4)"0)Q8M$)#C'1"0D
M`````(EL)#"+;"1`@<'6P6+*`<@S;"0P,VPD8(GI`<&)V,'@!8E$)"B)V(ML
M)"@/K/@;B40D.`ML)#B+1"0@`>F)3"0HB4PD8(G!P>$>#ZS0`HG+BY0DL`(`
M``G#BT0D0(G=B5PD.(M<)#"!PM;!8LH!T(M4)"PQZXML)%`QW8GI`<&+1"0H
MP>`%B40D((M$)"B+;"0@#ZS0&XGRB40D0`ML)$`!Z<'B'@^L_@*)U8E,)%")
M3"0@"?6+G"2X`@``BT0D,(GOBVPD.(M4)"2)?"1`@</6P6+*`=@Q_8GNBVPD
M8#'UB>D!P8M$)"")RXG&B<>+1"0HP>8%B70D,(MT)#`/K-<;BU0D+(G!QT0D
M+``````)_@'SP>$>,?\/K-`"B<V+C"3``@``BU0D)`G%BT0D.(E<)&");"0P
MBVPD0(G>@<'6P6+*`<@S;"0P,VPD4(GI`<&)V,'@!8E$)"B)V(ML)"@/K/@;
MB40D.`ML)#B+1"0@`>F)3"10B4PD*(G!P>$>#ZS0`HG+BY0DR`(```G#BT0D
M0(G=B5PD.(M<)#"!PM;!8LH!T#'KBVPD8#'=B>D!P8M$)"B+5"0LBYPDT`(`
M`,=$)"0`````P>`%B40D((M$)"B+;"0@#ZS0&XGRB40D0`ML)$"+1"0P`>G!
MXAX/K/X"B=6)3"1@BU0D)`GU@</6P6+*B4PD((GOBVPD.`'8B7PD0#']B=>)
M[HML)%`Q]8GI`<&+1"0@B<L/I,<%B<;!Y@6)?"0TB<>)="0PBT0D*(MT)#`/
MK-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-BXPDV`(``(G>"<6)7"10BT0D.(N<
M)-P"``");"0P@<'6P6+*BVPD0(/3`#'2`<@1VC-L)#`QVS-L)&")Z0'!B?`1
MT\'@!3'2B40D*(GP#ZSX&XE$)#B+;"0H"VPD.(M$)"#'1"0L``````'I$=.+
M5"0DB4PD*(E,)&")P8E<)&3!X1['1"0D``````^LT`*)RXN4).`"```)PXM$
M)$")W8E<)#B+7"0P@<+6P6+*`="+5"0L,>N+;"10,=V+G"3H`@``B>D!P8M$
M)"C!X`6)1"0@BT0D*(ML)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)
MU8E,)""+5"0D"?6!P];!8LJ)3"1`B>^+;"0X`=B)?"0P,?V)UXGNBVPD8#'U
MB>D!P8M$)"`/I,<%B<;!Y@6)?"14B<>)="10BW0D4`^LUQN+5"0L"?Z)\`'(
M,?^)QHM$)"B)P<'A'@^LT`*)S8M4)"0)Q8M$)"");"10B=.)P0^DRQ[!X1Z)
M3"0@B=&)P@^LR@+!Z0*+1"0XB5PD)(E,)"R+C"3P`@``BUPD,(E4)"B)^H'!
MUL%BR@'(,>N+;"1`,=V)Z0'!B?#!X`6)1"0XB?"+;"0X#ZSX&P^D\@6)1"1`
M"VPD0(E4)#R)^L'J&XE4)$2+5"1,B>B+;"0@`<B)P8M$)!@#3"00QT($````
M`,="#``````!\`ML)"B)0@B)"HGH`P0DB4(0BT0D4`-$)`C'0A0`````QT(<
M`````,=")`````")0AB+1"0P`T0D6(E"((N$)/P"``!E,P44````=0N!Q`P#
M``!;7E]=P^A8(0``D(VT)@````!55U93Z"?9__^!PX.1``"#[!R%P`^$JP``
M`(N+%`$``(L)A<F)3"0(#X27````#[8(A,ET:X#Y/71FB<:#Q@$/M@Z$R70%
M@/D]=?$IQHM,)`B+*87M=#:)5"0,B40D!(G/C;0F`````(/L!%;_="0,5>CZ
MU?__@\00A<!U!X!\-0`]="2#QP2++X7M==N#Q!R)Z%M>7UW#B?:-O"<`````
M,?;KJ8UT)@")^BM4)`B+1"0,C6PU`<'Z`HD0@\0<B>A;7E]=PS'MZ\2-M"8`
M````5U:)QE/H@MG__X'"LI```(/L$(NZ%`$``(U<)`AEH10```")1"0,,<")
MVHGPZ/[^__^%P'0[C78`C;PG`````(M4)`B+!XT$D(M0!(72B1!TUXVV````
M`(/`!(M0!(72B1!U](G:B?#HP_[__X7`=<^+1"0,93,%%````'4'@\006UY?
MP^CV'P``C;8`````55>)Q593B=;HP]?__X'#'Y```(/L.&6A%````(E$)"@Q
MP#'`@#H]#Y3``<96Z"[4__^#Q!")!"2)Z(U4)!CH7?[__X7`#X0-`0``@^P,
MB<=0Z`K4__^#Q!`Y!"0/AMX```"+1"08C0R%`````(N#%`$``(E$)`0/MD4`
MA,`/A)P!```\/0^$E`$``(GHZP:0@/H]=`J#P`$/MA"$TG7Q*>B+5"0$@^P,
MBSH!SXM,)`R-1`@"4.ANT___@\00A<")!P^$:P$``(M4)`2-30&+`HM4)!B+
M%)`/MD4`/#V(`G0CA,!U#^L=B?:-O"<`````/#UT$(/!`0^V0?^#P@&$P(@"
M=>S&`CTQP(VT)@`````/M@P&B$P"`8/``83)=?$QP(M<)!QE,QT4````#X4*
M`0``@\0L6UY?7<.-M@````"#Q@$/MD;_@\<!A,"(1_]U[^O,D(UT)@"+@Q0!
M``"+$(E$)`2+.H7_#X2X````,<#K"(VV`````(GXC7@!BPRZA<EU](T$A0P`
M``"+BW01``"%R70[@^P(4%+H@=+__XM,)!2#Q!"%P(D!#X2"````C0R]````
M`(E$)`B+1"0(QT2X!`````")?"08Z:?^__^)5"0(@^P,QX-T$0```0```%#H
M0=+__X/$$(7`=$2-#+T`````@^P$48M4)!")3"044HE$)!10Z'31__^+3"04
MBT0D&(/$$(D!BTPD#.N<,<#I>_[__[@(````,?_I6?___[C_____Z>7^___H
MKQT``.L-D)"0D)"0D)"0D)"0D%575E.)QNAUU?__@</1C0``@>R,````9:$4
M````B40D?#'`A?9T!8`^`'4DBT0D?&4S!10````/A40!``"!Q(P```!;7E]=
MPY"-M"8`````@^P,5NB7TO__@\00A<")QW3*C8/TC___B40D"(U$)!R)1"0,
MC70F`(/L#%?H+]+__X/$$(7`B<4/A,H````/ME43N"X```")P2G1=1L/ME44
MA=)TTRG0#X2;````]]B%P'3%ZP>-=@"%R72\@^P,5NA+T?__C543B40D%(D4
M)(E4)!#H.-'__XM,)!2-1`$"B00DZ/#0__^)Q5A:BU0D"%)6_W0D&&K_:@%5
MZ/C1__^#Q!S_="0056H#Z+G1__^#Q!"#^/]T$(M$)"PE`/```#T`0```=%&#
M[`Q5Z$C0__^#Q!"#[`Q5Z/S/__^#Q!#I-/___XUT)@`/MD45Z5[___^-M"8`
M````@^P,5^B'T?__B30DZ.?/__^#Q!#IN_[__XVT)@````")Z.B!_O__Z[+H
M&AP``(UV`(V\)P````!75HG'4^CFT___@<-"C```@^P,B[-,````_S;H(-'_
M_X/$#`4X`0``4%=J`^@7T?__@\00A<!T"%LQP%Y?PV:0@^P,_S;H]M#__XN`
M2`$``(/$$"4`\```/0!```!T'X/L#/\VZ-?0__^+@$@!``"#Q!`E`/```#T`
MH```=;J#[`AJ`E?H;]#__X/$$(7`#Y3`6P^VP%Y?PY"-M"8`````55>)QU93
MZ$73__^!PZ&+``"![#`0``!EH10```")A"0@$```,<")5"00:/\/``"-@_J/
M__^-="0D5E#H&,___X/$$(7`?F&-:/^`?"P<`'1/B<6#[`15:B]6Z,G/__^#
MQ!"%P'1"BX-,````@^P,_S#H*M#__U565U#H\<___X/$((N$)!P0``!E,P44
M````=3F!Q"P0``!;7E]=PXUV`(7M=:^-="8`BX-,````@^P,_S#HZ,___X/$
M#/]T)!!74.B:SO__@\00Z[?HH!H``%/H>M+__X'#UHH``(/L%(N#3````/\P
MZ+3/__^-DQ22__]2C9,)D/___[,T````4E#H`L___X/$*%O#D(UT)@!64^@Y
MTO__@<.5B@``@^P0B[-,````_S;H<\___XD$).B;____6/\VZ&//__]:C9/)
MD?__66H`4E*-DQ2+__]2C9,ED/__4E#H\\[__X/$)%M>PXVV`````(V\)P``
M``!55U93Z-?1__^!PS.*``"![!P@``!EH10```")A"0,(```,<#H]\W__XV3
M!9#__X/L"%)0C8,ZD/__4&@!$```:@&-="0F5N@,S___@\0@A<!X;8/L!&@`
M$```C;PD$Q```%=6Z'_-__^#Q!"%P(G%>$Z-0`&#[`Q0Z+K-__^#Q!"%P(G&
M=!*#[`155U#H#LW__\8$+@"#Q!"+C"0,(```93,-%````(GP=1F!Q!P@``!;
M7E]=PXUV`(V\)P`````Q]NO5Z#<9``"-M"8`````Z2O___^-="8`C;PG````
M`%575E/H]]#__X'#4XD``('L+!```(N$)$`0``"-5"08B[0D1!```(D$)(G'
M9:$4````B80D'!```#'`C8-(D/__Z(KW__^#[`B)Q6HO5^@MS?__@\00A<!T
M,8L\)(V#49#__XGZZ,;X__^)^(N4)!P0``!E,Q44````#X68`0``@<0L$```
M6UY?7<.#[`S_="0,Z/G,__]:68G'C8->D/__B40D#%!6Z&3-__^)QHU'`8/$
M$(E$)`B+@TP```")1"0,C;8`````A?9TCH`^``^$VP```(7M=!6#[`A65>BU
MR___@\00A<`/A*,```"#[`Q6Z)G,__^#Q!"`?`;_+W45C;0F`````(/H`8!\
M!O\OQ@0&`'3R`T0D"#W_#P``#X\U____C8-@D/__@^P$_W0D!%"-@X21__]6
M4&@`$```:@&-="0X5N@LS?__@\04BWPD&/\WZ/;,__^#Q`P%.`$``%!6:@/H
MW<S__X/$$(7`=1^#[`S_-^C4S/__BX!(`0``@\00)0#P```]`(```'17@^P(
M_W0D#&H`Z'',__^#Q!")QND?____C;0F`````(7M="2-@T:0__^Y`@```(GN
MB<?SIG3*B<:X`0```.E#____D(UT)@"-LT:0__^X`0```.DN____@^P(:@%6
MZ!7,__^#Q!"%P'67C8-1D/__B?+H*??__X/L#%;HN,O__X/$$.E4_O__Z`,7
M``"-=@"+1"0$#[8(A,ET%8U0`6:0@/DO#[8*#T3"@\(!A,EU\//#C;0F````
M`(V\)P````!64^BISO__@<,%AP``@^P4BW0D((7V=%`/MA:$TG1)B%0D#X/L
M#%;H%,O__XU$!O^#Q!`/ME0D#SG&<@OK'F:0@^@!.<9T&8`X+W3TZP=FD(`X
M+W1`@^@!.<9R]#G&=36`^B]U<XUV`(/L#&H"Z);*__^#Q!"%P'17NBX```!F
MB1"#Q!1;7L.)]HV\)P````"`."]U!X/H`3G&<O0I\(U0`H'Z`!```'<G@\`!
M:``0``!05HVS=`$``%;HX<K__X/$$(GP@\046U[#C;8`````@\04,<!;7L.-
M@V"0__^#[`Q0Z)'*__^#Q!#KE8UT)@!75E/HN,W__X'#%(8``(/L,&6A%```
M`(E$)"PQP(N#\)'__XUT)`2)1"0*BX/TD?__B40D#HN#^)'__XE$)!*+@_R1
M__^)1"06BX,`DO__B40D&HN#!)+__XE$)!Z+@PB2__^)1"0BBX,,DO__B40D
M)@^W@Q"2__]FB40D*HV#8I#__^C8]/__C8-KD/__Z,WT__^-@W.0___HPO3_
M_XV#?)#__^BW]/__C8.#D/__Z*ST__^-@Y.0___HH?3__XV#2)#__^B6]/__
MC8.?D/__Z(OT__^-@ZF0___H@/3__XV#LY#__^AU]/__C8-1D/__Z&KT__^-
M@[V0___H7_3__XV#QI#__^A4]/__C8/1D/__B?+H=_/__X7`=`V)PHV#J9#_
M_^C&]/__C8/BD/__B?+H6?/__X7`=`V)PHV#])#__^BH]/__C8/_D/__B?+H
M._/__X7`=#>)PHV#2)#__^B*]/__C9,KD?__C8.#D/__Z'GT__^+1"0L93,%
M%````'50@\0P6UY?PY"-="8`C8,/D?__B?+H\_+__X7`=`^)PHV#GY#__^A"
M]/__Z[:-="0;C;L@D?__N0H```#SIG6CC50D)8V#GY#__^@>]/__ZY+H!Q0`
M`(VT)@````!3Z-K+__^!PS:$``"#[!AEH10```")1"0,,<"+@SP!``"#^/]T
M&HM,)`QE,PT4````=4&#Q!A;PY"-M"8`````C50D"(V#GY#__^AA\O__A<!T
M'0^V$(#Z,`^5P(32#Y7"(=`/ML")@SP!``#KN&:0,<#K[^B'$P``C;0F````
M`%/H6LO__X'#MH,``(/L".@\Q___@^P,4.CKQO__@\00A<!T#(L`@\0(6\.0
MC70F`#'`Z_*-M@````"-OP````!55U93Z!?+__^!PW.#``"#[%R+1"1PC;LW
MD?__C;,MD?__QT0D2`````"-;"0PB7PD,(ET)#2)1"0(9:$4````B40D3#'`
MC8,ZD?__B40D.(V#,)'__XE$)#R-@S61__^)1"1`C8-'D?__B40D1(U$)"R)
M1"0,C8->D/__B40D%(V#A)'__XE$)!CK*(UT)@"#[`C_="004(E$)"#H#\;_
M_X/$$(7`=$B#Q02%]G0KB?>+=02+5"0,B?CH,?'__X7`=`6`.`!UR(M4)`B)
M^(/%!.AZ\O__A?9UU8M$)$QE,P44````=6Z#Q%Q;7E]=PY"#[`S_="04Z+3&
M__^+3"0@B40D+(D,)(E,)"#HH,;__XM4)"R-1`("B00DZ%C&__^#Q`R+3"04
M4?]T)!S_="04_W0D*&K_:@%0B40D,.A6Q___@\0@BU0D$(GXZ`#R___I4___
M_^CF$0``C;8`````55=64^@B$0``@<43@@``@>P\@0``BX0D4($``(U4)#R-
MG5*1___'1"1(`````,=$)&P`````B5PD3,=$)%0`````B40D'(E4)!1EH10`
M``")A"0L@0``,<"-A5Z1__^)1"1`C85&D/__B40D1(V%])#__XE$)`R)1"18
MC87MD/__B40D7(V%8Y'__XE$)&"-A0J1__^)1"1DC85KD?__B40D:(V%;Y'_
M_XE$)%"-A4B0___HV.___X7`=`F`.``/A7L$``#HEOW__X7`B<8/A),$``"#
M[`R)ZU;H<<7__XU$``&)!"3H+<7__XE$)""#Q!"`/@!T-HV%>)'__XM\)!")
M!"2-="8`#[8&@^P,B>N#Q@%0_W0D$&K_:@%7@\<"Z!/&__^#Q""`/@!UVXU<
M)%B+1"0,BWPD%.L.D(UT)@"#PP2+`X7`="^)^NA`[___A<")QG3J@#@`=.7H
M</3__X7`=-R#[`R)ZU;H&<7__X/$$(7`B<=U0HM<)$`Q]NL+@\8!BURT0(7;
M="V`.P!T*(G8Z#GT__^%P'3E@^P,4XGKZ.+$__^#Q!"%P'33B<?K"8VT)@``
M```Q_X/L#(GK5^B+Q/__@\00BTPD$(L9@\$$C9/__O[^]],AVH'B@("`@'3I
MB=/!ZQ#WPH"````/1-.-60(/1,N)TP#3B>N#V0,K3"00@^P,C;0!!`0``%;H
M!,3__XE$)!R)P8V%?9'___]T)"!0C85@D/__B40D*%"-A8*1__]7B<]0:O]J
M`5'H],3__X/$*&C``0``5^@NQ/__@\00@_C_#X22````B[U,````@^P,B>O_
M-^B@Q/__@\0,!3@!``!0_W0D%&H#Z)3$__^)1"0P@\00A<`/A*4```"#[`R)
MZ_]T)!B+1"0L_S"-A5R2__]0BX4@````:@'_,.A`Q/__@\0@QT0D&`````"+
MC"0L@0``93,-%````(M$)!@/A4D*``"!Q#R!``!;7E]=PXUV`(V\)P````#H
MF\/__XL`@_@1#X1>____@^P(4/]T)!B+1"0L_S"-A2"2__]0BX4@````:@'_
M,.C4P___@\0@QT0D&`````#KDHVT)@````"#[`S_-^C.P___BX!(`0``@\00
M)0#P```]`$````^%./___X/L#/\WZ*O#__^+@%`!``")1"00Z#S"__^#Q!`Y
M!"0/A1/___^#[`S_-^B&P___BX!(`0``@\00)?\!```]P`$```^%\/[__X/L
M#(GK5NAJPO__BU0D)(E$)"B-A3"1___HS^S__X/$$(7`#X0$`@``@^P,B>M0
MZ+'"__]:65"+1"0H_S#HV_3__XE$)!"#Q!"%P`^$W`$``(/L#(GKBWPD#%?H
M3<+__X/$$(/X`WXMC70'_(G[C;V+D?__N04```#SIG48@_@$#X2F!P``@'P#
M^R\/A)L'``"-="8`Z*/Y__^%P'4?@^P(B>MJ`/]T)`SH#\+__XE$)"R#Q!"%
MP`^%?@$``(V5*Y'__XVUR9'__XV%GY#__XGKC;VRD?__Z''M___H?,'__U90
MC86DD?___W0D&/]T)!A0:O]J`?]T)#3HEL+__X/$((DT)(E\)!2+="0@BWPD
M&.M`C78`C;PG`````.C+P?__@S@1=42)ZX/&`>@LP?__@^P,_W0D#%90_W0D
M*/]T)"C_="0T:O]J`5?H1<+__X/$,(/L"(GK:,`!``!7Z'K!__^#Q!"#^/]T
MLH/L#(GK_W0D&.A<P/__BWPD*(V%2)#__XGZZ,/L__^)/"3H:_G__X/$$.F&
M_?__C78`@^P,B>M0B40D$.A1^?__BT0D$(D$).@MP?__B40D*(/$$.E<_?__
MOP$```")V(MT)!3K#XUT)@"+1+Q,@\<!A<!T*8GRZ`;K__^%P'3J@#@`=.6#
M[`R)ZU#HZL#__X/$$(7`=-.)QNDH^___@^P,B>N-M5>1__]J#>A:P/__B40D
M((/$$.DM^___C;8`````BT0D'(L`B00DZ1;^__]J`FK_:NZ+?"0H5^@*P/__
M@\0,:@:-A"0T`0``B40D'%!7Z%N___^#Q!"`O"0L`0```'4.@+PD+0$``$,/
MA&\&``!J`&H`B>MJ`/]T)"CHQ[___\>$)(`````!(T5GQX0DA`````````#'
MA"2(````B:O-[\>$)(P`````````QX0DD````/[<NIC'A"24`````````,>$
M))@```!V5#(0QX0DG`````````#'A"2@````\.'2P\>$)*0`````````QX0D
MJ`````````#'A"2L`````````,>$)+``````````QX0DM`````````#'A"3X
M`````````(/$$(U$)'")+"2)1"0LC80DJ````(E$)""0@^P$:`"```#_="0<
M_W0D*(M<)!#H5[[__X/$$(7`B<8/C@L"``"+C"28````BYPDG````(GPB?7!
MX`.)]\']'P'(@_L`#X?-`0``.<$/A\4!``"+C"2@````BYPDI````(F$))@`
M``")^(GJ#ZSH'<'J'<>$))P``````````<B)A"2@````BX0DZ````!':B90D
MI````(7`#X1I`0``OT`````IQSG^#T[^`T0D((/L!%?_="0<4(M<)!#HS[W_
M_XN$)/@````!^(F$)/@```"#Q!"#^$`/A2/___^+1"0L*?X#?"04Z!3#__^-
M="8`@_X_#X[H````C4;`BVPD+(G^B40D*,'H!HU8`8E$)"3!XP8!^XUV`(L&
M@\9`B80DJ````(M&Q(F$)*P```"+1LB)A"2P````BT;,B80DM````(M&T(F$
M)+@```"+1M2)A"2\````BT;8B80DP````(M&W(F$),0```"+1N")A"3(````
MBT;DB80DS````(M&Z(F$)-````"+1NR)A"34````BT;PB80DV````(M&](F$
M)-P```"+1OB)A"3@````BT;\B80DY````(GHZ#_"__\Y\P^%3____XM,)"B)
MR(/@P(U\!T"+1"0DP>`&*<&)SFI$5E?_="0LBUPD$.A&O?__B;0D^````(/$
M$.G__?__C;0F`````(M\)!3IW_[__XVT)@````"+C"2@````BYPDI````(/!
M`8/3`.DP_O__BRPD@^P,_W0D*(GKZ.Z]__^+A"2P````BYPDJ````(NT)*P`
M``"+E"2T````B40D$(G8#ZSP`XE4)!2#X#^-4`'&A`2X````@(/$$(/Z.`^/
MI`(``+@X````*=`#5"0@@_@$#X/)`@``A<!T"Z@"Q@(`#X5_`P``BU0D!(L$
M)(B<).<````/K-`8BU0D!(B$).````"+!"0/K-`0BU0D!(B$).$```"+!"0/
MK-`(B(0DX@````^V!"2(A"3C````B=@/K/`8B(0DY````(G8#ZSP$(B$).4`
M``")V`^L\`B(A"3F````BT0D+.C?P/__BW0D<(M\)'2)\0^L^1B(C"3O````
M#[;!B?$/K/D0B(PD\````(GQ#ZSY"(M\)'R(C"3Q````B?&+="1XB(PD\@``
M`(GQ#ZSY&(B,)/,```")\0^L^1"(C"3T````B?$/K/D(B[PDA````(B,)/4`
M``")\8NT)(````"(C"3V````B?$/K/D8B(PD]P```(GQ#ZSY$(B,)/@```")
M\0^L^0B+O"2,````B(PD^0```(GQB[0DB````(B,)/H```")\0^L^1B(C"3[
M````B?$/K/D0B(PD_````(GQ#ZSY"(N\))0```"(C"3]````B?&+M"20````
MB(PD_@```(GQ#ZSY&(B,)/\```")\0^L^1"(C"0``0``B?$/K/D(C;PD*P$`
M`(B,)`$!``")\8VT)/````"(C"0"`0``C8PD`P$``(E,)!R)RHV->)'__XD,
M)(E\)!2)]XG6Z0<```"0#[8'@\<!@^P,B>M0_W0D$&K_:@%6@\8"Z*N[__^#
MQ"`Y="04==J-A<F1___&A"0K`0```(GK4(V%E9'___]T)"#_="08_W0D&%!J
M_VH!_W0D-.AQN___@\0@Z3_Y__^+1"0<BU`$A=(/A%KX__^#[`R)ZU*)5"0D
MZ&.Z__^#Q!"#^`,/AC_X__^+5"04C;V0D?__N04```"-=`+\\Z8/110DB10D
MZ1[X__^+3"0@N$`````!T2G0B<)T#3'`Q@0!`(/``3G0<O6+1"0LZ*^^__^+
M?"0@N0X````QP/.KZ4;]__^-2@3'`@````#'1`+\`````(/A_"G*`<*#XOR#
M^@0/@B+]__^#XOPQP,<$`0````"#P`0YT'+RZ0K]__^`O"0N`0``00^%@_G_
M_X"\)"\!``!##X5U^?__@+PD,`$``$@/A6?Y__^`O"0Q`0``10^%6?G__VH"
M:O]JQHMT)"A6Z"&Y__^#Q`QJ*8M\)!Q75NAYN/__C87)D?__4(V%E9'__U?_
M="0H_W0D*%!J_VH!_W0D1.@MNO__@\0PZ?OW__^0C70F`#')9HE,`O[I=?S_
M_^BW!```C;0F`````%575E/HA[S__X'#XW0``(/L.(NK3````&6A%````(E$
M)"@QP/]U`.BTN?__7_]U`(G&Z*FY__\/MD!DB$9EC40D*(E$)!R)PHV#@Y#_
M_^@-X___@\00A<!T"8`X,0^$?0(``.AH[O__@^P,_W4`Z&VY__^-D\.1__]J
M"VH!4E#H;+C__X/$((7`#X2R````BT`,@[M\$0```8M`&(E$)`0/CIL````Q
M_[X!````ZRV0BT(,@^P(4(N#>!$``/\TL.ACM___@\00A<!U9(N#?!$``(/&
M`8/'`3GP?EJ#[`S_=0#H^;C__VH`5_]T)!Q0Z+2X__^#Q""%P'0UBQ"+0@@E
M``0@`#T`!```=*2)5"0(@^P,_W4`Z,6X__]J`FH`BU0D(%)0Z'ZW__^#Q"#K
MA)"+@WP1``"-4/\Y^@^$7P$``(/L#/]U`.B4N/__C9/(D?__:@-J`5)0Z).W
M__^#Q""%P(G&=#.+0`R#[`R+./]U`.AJN/__C9/*D?__@\0,4E=0Z!FW__^+
M1@R#Q!"+,/9&"D`/A;`!``"#[`S_=0#H/+C__XV3SY#__VH#:@%24.@[M___
M@\0@A<")QG0WBU0D#(V#49#__^B3X?__A<")QP^$20$``(M&#(/L#(LP_W4`
MZ/FW__^#Q`Q75E#HKK;__X/$$(/L#/]U`.C@M___C9//D?__@\0,:@%24.@F
MM___B<98_W4`Z,.W__^-D^21__^#Q`Q25E#H<K;__UK_=0#HJ;?__XM4)!S&
M0&4`C8-(D/__Z!;A__^#Q!"%P(G&B8.`$0``#X23````@^P(:,`!``!6Z.6V
M__^-4`&#Q!"#^@%V"8/X$0^%ZP```(M$)!QE,P44````#X75````@\0L6UY?
M7<.0C;0F`````(/X`0^.F/[__XM\)`2^`0```(VV`````(/L#/]U`(/&`>@:
MM___6EE74.B)M?__@\00.;-\$0``?][I8O[__Y"`>`$`#X1^_?__Z73]__^0
M@^P,_[-X$0``Z-+O__^#Q!"%P(G&B8.`$0``#X5,____C8.PDO__@^P,4.@@
MMO__BX-X$0``@^P,BSB+1@R+,/]U`.BHMO__B?J)\.C_Y?__@\00Z:S^__^#
M[`S_=0#HC+;__UE?5E#H&[;__X/$$.DT_O__Z$8!``!0BX-X$0``5O\PC8/4
MDO__4.C`M?__5U93BW0D$.@$N?__@<-@<0``@^P,5NA%ZO__#[8(@\00A,ET
M2(U0`8G'C;8`````@/DO#[8*#T3Z@\(!A,EU\.CK[/__A?9T((7`=!R`/@!T
M%XV#?9'__X/L"%!7Z#ZT__^#Q!`Y^'0(6UY?PXG'Z\];B?!>7^D5X___BRPD
MPY!3Z(JX__^!P^9P``"#[`B-@S@!``"%P'0?BP!0_W0D'/]T)!S_="0<Z).T
M__^#Q!A;PXVV`````#'`Z]]FD&:055=64^A'N/__@<.C<```@^P,BVPD((VS
M"/___^B+L___C8,$____*<;!_@*%]G0E,?^-M@````"#[`3_="0L_W0D+%7_
ME+L$____@\<!@\00.?YUXX/$#%M>7UW#C78`\\-FD&:09I!FD&:09I!FD%/H
MVK?__X'#-G```(/L".BTL___4X/L".C#M___@<,?<```@\0(6\,#`````0`"
M`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%2
M7T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,
M24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-4
M14T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S
M)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E
M<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ5D524TE/
M3@`Q+C`S-0`M90`M+0!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`````!P97)L>'-I+F,````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C
M(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P
M;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL
M96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D
M8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*
M8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M
M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@
M86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!
M4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@
M)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*
M9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@
M+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@
M)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F
M86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?
M1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R
M;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`]
M(')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@
M,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T
M.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F
M<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@
M7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O
M=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE
M;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN
M="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M
M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ
M,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F
M:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P
M*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H
M)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N
M86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L
M<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R
M;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM
M>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I
M;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#
M3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U
M<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E
M9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R
M;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A
M<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("([
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#
M3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``1L#.^@````<````D'+_
M_P0!``"0=/__G`T``$!X__\H`0``X)W__VP!``"PGO__T`$``$"?__\(`@``
MD*'__X@"```@H___0`,``,"C__^P`P``D*3__TP$``#0I/__?`0``#"E___(
M!````*;__UP%```0IO__<`4``#"H__]L!@``8*C__X`&``!0J?__]`8``#"K
M__\L!P``L*O__U`'``#PJ___?`<``%"M___P!P``@+K__]@+````OO__3`T`
M`'N^___D#0``@+[___@-``#`OO__+`X``""___]X#@``,+___XP.```4````
M``````%Z4@`!?`@!&PP$!(@!```@````'````(1Q__\0``````X(1@X,2@\+
M=`1X`#\:.RHR)")`````0````!!W__^8)0```$$."(4"00X,AP-$#A"&!$$.
M%(,%1@Z@!@.!)0H.%$'##A!!Q@X,0<<."$'%#@1!"P```&````"$````;)S_
M_\D`````00X(A0)!#@R'`T$.$(8$00X4@P5.#C`"60XT00XX1`X\00Y`2`XP
M5PH.%$/##A!!Q@X,0<<."$'%#@1*"UX*#A1#PPX00<8.#$''#@A!Q0X$00LT
M````Z````-B<__^*`````$$."(<"00X,A@-##A"#!$X.(`)N"@X00<,.#$'&
M#@A!QPX$00L``'P````@`0``,)W__T$"````00X(A0)!#@R'`T,.$(8$00X4
M@P50#DQ7#E!(#D!9#DQ##E!(#D`"3PY,30Y02`Y``G@*#A1!PPX00<8.#$''
M#@A!Q0X$1PL"6`Y(00Y,00Y03`Y`<0Y,2PY02`Y`3@Y$00Y(20Y,10Y04`Y`
M````M````*`!````G___A@$```!!#@B%`D$.#(<#00X0A@1!#A2#!5,.H`%L
M"@X40<,.$$'&#@Q!QPX(0<4.!$D+0PZL`4$.L`%(#J`!7PZL`4$.L`%(#J`!
M>PZL`4$.L`%K#JP!00ZH`44.K`%!#K`!1`ZT`4(.N`%"#KP!00[``4@.I`%$
M#J@!00ZL`4(.L`%(#J`!6`ZL`4$.L`%(#J`!0PZL`4$.L`%(#J`!7`ZL`4$.
ML`%0#J`!`&P```!8`@``V)___Y@`````00X(AP)!#@R&`T,.$(,$3@X<2`X@
M2`X41@X800X<0@X@2`X010K##@Q#Q@X(0<<.!$,+0PX<0@X@3@X03PX<0@X@
M3@X03PX80@X<00X@2`X01L,.#$3&#@A!QPX$``"8````R`(```B@___0````
M`$$."(4"00X,AP-##A"&!$$.%(,%40[$(%@.R"!+#LP@00[0($@.P"!3#L0@
M00[(($(.S"!!#M`@2`[`($T.S"!"#M`@1@[4($$.V"!!#MP@00[@($@.P"!6
M"@X40<,.$$'&#@Q!QPX(0<4.!$0+40[,($(.T"!(#L0@1`[(($$.S"!!#M`@
M2`[`(``L````9`,``#R@__\[`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP
M2`X(0<,.!`!(````E`,``$R@__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"
M#B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!```D````.`#
M``!@H/__R0````!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L$!=#KA`00Z\0$$.
MP$!'#L1`10[(0$(.S$!%#M!`2`ZP0$<.M$!%#KA`2`Z\0$$.P$!(#K!`3`Z\
M0$$.P$!(#K!`20ZT0$$.N$!!#KQ`00[`0$P.L$!8"@X40<,.$$'&#@Q!QPX(
M0<4.!$L+`!````!T!```G*#__P4`````````^````(@$``"8H/__'0(```!!
M#@B%`D$.#(<#00X0A@1!#A2#!5$.P"!T#L@@1`[,($$.T"!(#L`@<`H.%$'#
M#A!!Q@X,0<<."$'%#@1!"T,.S"!$#M`@1@[,($$.R"!-#LP@00[0($T.P"!H
M#L@@00[,($$.T"!(#L`@2P[,($$.T"!(#L`@=`[$($0.R"!!#LP@1P[0($$.
MU"!%#M@@0@[<($4.X"!(#LP@1@[0($@.Q"!&#L@@00[,($(.T"!(#L`@1P[,
M($(.T"!.#L`@3P[(($0.S"!"#M`@2`[`(`))#L@@0@[,($$.T"!(#L`@5`[,
M($$.T"!(#L`@$````(0%``"\H?__(@````````!P````F`4``-BA___L````
M`$$."(8"00X,@P-.#B!6#BQ!#C!,#B!X#BQ"#C!(#B!/"@X,0<,."$'&#@1*
M"V$.)$$.*$$.+$<.,$@.($4*#@Q!PPX(0<8.!$<+0PH.#$/##@A!Q@X$00M)
M#BQ!#C!(#B```#0````,!@``5*+__]D!````00X(AP)!#@R&`T$.$(,$3@Y`
M`W8!"@X00<,.#$'&#@A!QPX$1@L`(````$0&``#\H___>0````!!#@B#`DX.
M(&<*#@A!PPX$20L`*````&@&``!8I/__-`````!!#@B#`DX.$$@.'$$.($@.
M$$D*#@A!PPX$1@MP````E`8``&RD__]:`0```$$."(4"00X,AP-!#A"&!$$.
M%(,%3@YP`H$.>$0.?$$.@`%,#G`"1@H.%$'##A!!Q@X,0<<."$'%#@1""T,.
M?$0.@`%L#G1%#GA$#GQ$#H`!1`Z$`4(.B`%"#HP!00Z0`4P.<.0#```(!P``
M6*7__RD-````00X(A0)!#@R'`T$.$(8$00X4@P51#M""`@+"#MR"`D,.X(("
M6`[0@@)<#MR"`D8.X(("1`[D@@)"#NB"`D(.[(("00[P@@)+#M""`G\.W(("
M0P[@@@)(#M""`FP.W(("00[@@@)*#M""`E0.W(("0P[@@@)(#M""`G\.W(("
M2`[@@@)5#N2"`D$.Z(("2P[L@@)'#O""`D,.](("0@[X@@)"#OR"`D$.@(,"
M2`[8@@)%#MR"`D$.X(("2`[0@@)2#MR"`D0.X(("2`[4@@)&#MB"`D0.W(("
M0@[@@@),#M""`DL.W(("1@[@@@)&#N2"`D<.Z(("2`[L@@)"#O""`D@.T(("
M9@H.%$'##A!!Q@X,0<<."$'%#@1+"U,.V(("00[<@@)$#N""`D8.Y(("1P[H
M@@)(#NR"`D(.\(("2`[0@@)4#MR"`D(.X(("3@[0@@)3#MR"`D(.X(("5P[0
M@@),#MR"`D(.X(("3@[0@@)3#MR"`D,.X(("6P[0@@)+#MR"`D,.X(("1@[<
M@@)!#MB"`D$.W(("1@[@@@),#M""`DL.W(("1P[@@@)(#M""`GX.V(("1`[<
M@@)$#N""`DP.T((";0[4@@)!#MB"`DH.W(("1`[@@@)!#N2"`D(.Z(("0@[L
M@@)$#O""`D@.T(("<@[<@@)$#N""`D$.Y(("00[H@@)$#NR"`D0.\(("1`[T
M@@)"#OB"`D(._(("00Z`@P)(#M""`D,.V(("1P[<@@)!#N""`D@.T(("2`[<
M@@)&#N""`F$.T(("2P[<@@)##N""`EP.T(("=`[<@@)##N""`D@.T(("3@[<
M@@)*#N""`DP.T(("6P[4@@)"#MB"`D(.W(("10[@@@)(#M2"`D(.V(("3`[<
M@@)!#N""`D@.T(("6@[4@@)"#MB"`D0.W(("1`[@@@("K0[0@@):#M2"`D4.
MV(("1`[<@@)$#N""`DP.T(("`I8.U(("00[8@@)$#MR"`D$.X(("7`[0@@(#
M#P$.U(("00[8@@)!#MR"`D0.X(("4P[0@@)[#MR"`D0.X(("`D(.T(("`PP"
M#MR"`D,.X(("1`[D@@)"#NB"`D(.[(("00[P@@)+#M""`E<.U(("2@[8@@)$
M#MR"`D0.X(("00[D@@)"#NB"`D(.[(("1`[P@@)(#M""`E<.W(("0P[@@@),
M#M""`@+9#M2"`D(.V(("0@[<@@)%#N""`D@.U(("0@[8@@)%#MR"`D$.X(("
M3`[D@@)'#NB"`D0.[(("1`[P@@)!#O2"`D(.^(("0@[\@@)$#H"#`D@.T(("
M``!P`0``\`H``*"N__^``P```$$."(4"00X,AP-!#A"&!$$.%(,%3@Y,50Y0
M1@Y,0PY09@Y`50Y,0PY030Y40@Y800Y<00Y@2`Y`;PY(00Y,20Y02`Y`5PY,
M0PY01PY400Y81`Y<00Y@2`Y`7`Y,0PY01PY40@Y810Y<00Y@2`Y`5PY,0PY0
M30Y40@Y800Y<00Y@2`Y`3`Y,10Y03@Y$00Y(00Y,00Y02PY`3PY,0PY030Y4
M0@Y800Y<00Y@2`Y`90Y,10Y02`Y$00Y(00Y,00Y02`Y`0PY,0PY03@Y$0@Y(
M00Y,00Y02`Y,0PY03@Y$00Y(00Y,00Y01@Y,0PY06PY`4PY(10Y,00Y02PY`
M8@H.%$'##A!!Q@X,0<<."$'%#@1)"UL.3$,.4$D.3$$.2$$.3$$.4$@.0&$*
M#DQ&#E!(#D!9#DQ!#E!%"TD.3$H.4%$.0$@.3$,.4$8.3$$.2$$.3$$.4$@.
M0$L.1$<.2$(.3$<.4`!,````9`P``*RP__][`````$$."(<"00X,A@-!#A"#
M!%(.'$$.($L.$'H.&$$.'$$.($@.$$4*PPX,0<8."$''#@1!"T7##@Q#Q@X(
M0<<.!$0```"T#```[&;__T`"````1`P!`$<0!0)U`$8/`W5P!A`'`G5\$`8"
M=7@0`P)U=`-[`0K!#`$`0<-!QD''0<5##`0$00L``!````#\#```C[#__P0`
M````````,````!`-``"`L/__/`````!!#@B#`DX.$$T.%$0.&$0.'$0.($@.
M"$'##@1'#A"#`@```$@```!$#0``C+#__UT`````00X(A0)!#@R'`T$.$(8$
M00X4@P5.#B!I#B1$#BA$#BQ!#C!-#B!'#A1!PPX00<8.#$''#@A!Q0X$```0
M````D`T``*"P__\"`````````!@```"D#0``G+#__Q0`````00X(@P).#A``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&`7```0%P``
M``````$````!`````0```-\!```!````+@(```P```#,$0``#0```*1>```9
M````T,T``!L````$````&@```-3-```<````!````/7^_V^L`0``!0```/P(
M```&````C`(```H```#O!```"P```!`````5``````````,```#,S@``$0``
M`%P/```2````<`(``!,````(````&`````````#[__]O`0``"/[__V^\#@``
M____;P(```#P__]O[`T``/K__V\%````````````````````````````````
M`````````````````````````-S-````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#P$P``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````30``#_____Y&$``$=#0SH@*%5B=6YT=2`V+C(N
M,"TX=6)U;G1U,2D@-BXR+C`@,C`Q-C$P,3D`1T-#.B`H56)U;G1U(#8N,BXP
M+35U8G5N='4Q,BD@-BXR+C`@,C`Q-C$P,#4``"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YI;FET`"YP;'0`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N:F-R`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``(```````````````!``````````A````!P````(```"(`0``B`$`
M`"0```````````````0`````````-````/;__V\"````K`$``*P!``#@````
M!0`````````$````!````#X````+`````@```(P"``",`@``<`8```8````!
M````!````!````!&`````P````(```#\"```_`@``.\$``````````````$`
M````````3@```/___V\"````[`T``.P-``#.````!0`````````"`````@``
M`%L```#^__]O`@```+P.``"\#@``H`````8````"````!`````````!J````
M"0````(```!<#P``7`\``'`"```%``````````0````(````<P````$````&
M````S!$``,P1```C```````````````$`````````'D````!````!@```/`1
M``#P$0``$```````````````$`````0```!^`````0````8`````$@```!(`
M`/`!``````````````@`````````AP````$````&````\!,``/`3``"T2@``
M```````````0`````````(T````!````!@```*1>``"D7@``%```````````
M````!`````````"3`````0````(```"X7@``N%X``*A```````````````0`
M````````FP````$````"````8)\``&"?``#L```````````````$````````
M`*D````!`````@```$R@``!,H```P`T`````````````!`````````"S````
M#@````,```#0S0``T+T```0```````````````0````$````OP````\````#
M````U,T``-2]```$```````````````$````!````,L````!`````P```-C-
M``#8O0``!```````````````!`````````#0````!@````,```#<S0``W+T`
M`/`````&``````````0````(````@@````$````#````S,X``,R^```T`0``
M```````````$````!````-D````!`````P````#0````P```$```````````
M````!`````````#?````"`````,````@T```$,```#00`````````````"``
M````````Y`````$````P`````````!#```!9```````````````!`````0``
I``$````#``````````````!IP```[0```````````````0``````````
